
'''
This file is automatically generated; Do not edit it. :)
'''
VERSION_INFO = {
    'final': True,
    'version': '1.22.0',
    'branch_nick': 'feature-0-Release__1_22_0_preparation',
    'revision_id': 'ccddc8939d452618f605ff63ba612fe5edad9317',
    'revno': 9342
}
